@@ -1,6 +1,8 @@
 package cmd
 
 import (
+	"errors"
+	"io/fs"
 	"os"
 
 	"github.com/caarlos0/log"
@@ -22,7 +24,7 @@ func loadConfig(path string) (config.Project, error) {
 		"goreleaser.yaml",
 	} {
 		proj, err := config.Load(f)
-		if err != nil && os.IsNotExist(err) {
+		if err != nil && errors.Is(err, fs.ErrNotExist) {
 			continue
 		}
 		return proj, err
