@@ -32,7 +32,7 @@ func setup(tb testing.TB) string {
 	folder := tb.TempDir()
 	require.NoError(tb, os.Chdir(folder))
 
-	createGoreleaserYaml(tb)
+	createGoReleaserYaml(tb)
 	createMainGo(tb)
 	goModInit(tb)
 	testlib.GitInit(tb)
@@ -66,7 +66,7 @@ go 1.20
 `)
 }
 
-func createGoreleaserYaml(tb testing.TB) {
+func createGoReleaserYaml(tb testing.TB) {
 	tb.Helper()
 	yaml := `build:
   binary: fake
