@@ -53,7 +53,7 @@ func (*Builder) WithDefaults(build config.Build) (config.Build, error) {
 	}
 	if len(build.Targets) == 0 {
 		if len(build.Goos) == 0 {
-			build.Goos = []string{"linux", "darwin"}
+			build.Goos = []string{"linux", "darwin", "windows"}
 		}
 		if len(build.Goarch) == 0 {
 			build.Goarch = []string{"amd64", "arm64", "386"}
@@ -165,7 +165,23 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		return err
 	}
 
-	env := append(ctx.Env.Strings(), details.Env...)
+	env := []string{}
+	// used for unit testing only
+	testEnvs := []string{}
+	env = append(env, ctx.Env.Strings()...)
+	for _, e := range details.Env {
+		ee, err := tmpl.New(ctx).WithEnvS(env).WithArtifact(a).Apply(e)
+		if err != nil {
+			return err
+		}
+		log.Debugf("env %q evaluated to %q", e, ee)
+		if ee != "" {
+			env = append(env, ee)
+			if strings.HasPrefix(e, "TEST_") {
+				testEnvs = append(testEnvs, ee)
+			}
+		}
+	}
 	env = append(
 		env,
 		"GOOS="+options.Goos,
@@ -176,6 +192,10 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		"GOAMD64="+options.Goamd64,
 	)
 
+	if len(testEnvs) > 0 {
+		a.Extra["testEnvs"] = testEnvs
+	}
+
 	cmd, err := buildGoBuildLine(ctx, build, details, options, a, env)
 	if err != nil {
 		return err
@@ -186,7 +206,7 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 	}
 
 	if build.ModTimestamp != "" {
-		modTimestamp, err := tmpl.New(ctx).WithEnvS(env).WithArtifact(a, map[string]string{}).Apply(build.ModTimestamp)
+		modTimestamp, err := tmpl.New(ctx).WithEnvS(env).WithArtifact(a).Apply(build.ModTimestamp)
 		if err != nil {
 			return err
 		}
@@ -314,7 +334,7 @@ func processFlags(ctx *context.Context, a *artifact.Artifact, env, flags []strin
 }
 
 func processFlag(ctx *context.Context, a *artifact.Artifact, env []string, rawFlag string) (string, error) {
-	return tmpl.New(ctx).WithEnvS(env).WithArtifact(a, map[string]string{}).Apply(rawFlag)
+	return tmpl.New(ctx).WithEnvS(env).WithArtifact(a).Apply(rawFlag)
 }
 
 func run(ctx *context.Context, command, env []string, dir string) error {
@@ -324,9 +344,11 @@ func run(ctx *context.Context, command, env []string, dir string) error {
 	cmd.Env = env
 	cmd.Dir = dir
 	log.Debug("running")
-	if out, err := cmd.CombinedOutput(); err != nil {
+	out, err := cmd.CombinedOutput()
+	if err != nil {
 		return fmt.Errorf("%w: %s", err, string(out))
 	}
+	log.Debug(string(out))
 	return nil
 }
 
