@@ -422,7 +422,7 @@ func TestBuild(t *testing.T) {
 	require.ElementsMatch(t, ctx.Artifacts.List(), []*artifact.Artifact{
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join(folder, "dist", "linux_amd64", "bin", "foo-v5.6.7"),
+			Path:   filepath.Join("dist", "linux_amd64", "bin", "foo-v5.6.7"),
 			Goos:   "linux",
 			Goarch: "amd64",
 			Type:   artifact.Binary,
@@ -435,7 +435,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join(folder, "dist", "linux_mips_softfloat", "bin", "foo-v5.6.7"),
+			Path:   filepath.Join("dist", "linux_mips_softfloat", "bin", "foo-v5.6.7"),
 			Goos:   "linux",
 			Goarch: "mips",
 			Gomips: "softfloat",
@@ -449,7 +449,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join(folder, "dist", "linux_mips64le_softfloat", "bin", "foo-v5.6.7"),
+			Path:   filepath.Join("dist", "linux_mips64le_softfloat", "bin", "foo-v5.6.7"),
 			Goos:   "linux",
 			Goarch: "mips64le",
 			Gomips: "softfloat",
@@ -463,7 +463,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join(folder, "dist", "darwin_amd64", "bin", "foo-v5.6.7"),
+			Path:   filepath.Join("dist", "darwin_amd64", "bin", "foo-v5.6.7"),
 			Goos:   "darwin",
 			Goarch: "amd64",
 			Type:   artifact.Binary,
@@ -476,7 +476,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join(folder, "dist", "linux_arm_6", "bin", "foo-v5.6.7"),
+			Path:   filepath.Join("dist", "linux_arm_6", "bin", "foo-v5.6.7"),
 			Goos:   "linux",
 			Goarch: "arm",
 			Goarm:  "6",
@@ -490,7 +490,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7.exe",
-			Path:   filepath.Join(folder, "dist", "windows_amd64", "bin", "foo-v5.6.7.exe"),
+			Path:   filepath.Join("dist", "windows_amd64", "bin", "foo-v5.6.7.exe"),
 			Goos:   "windows",
 			Goarch: "amd64",
 			Type:   artifact.Binary,
@@ -503,7 +503,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7.wasm",
-			Path:   filepath.Join(folder, "dist", "js_wasm", "bin", "foo-v5.6.7.wasm"),
+			Path:   filepath.Join("dist", "js_wasm", "bin", "foo-v5.6.7.wasm"),
 			Goos:   "js",
 			Goarch: "wasm",
 			Type:   artifact.Binary,
@@ -558,7 +558,7 @@ func TestBuildInvalidEnv(t *testing.T) {
 	err := Default.Build(ctx, build, api.Options{
 		Target: runtimeTarget,
 		Name:   build.Binary,
-		Path:   filepath.Join(folder, "dist", runtimeTarget, build.Binary),
+		Path:   filepath.Join("dist", runtimeTarget, build.Binary),
 		Ext:    "",
 	})
 	testlib.RequireTemplateError(t, err)
@@ -591,7 +591,7 @@ func TestBuildCodeInSubdir(t *testing.T) {
 	err = Default.Build(ctx, build, api.Options{
 		Target: runtimeTarget,
 		Name:   build.Binary,
-		Path:   filepath.Join(folder, "dist", runtimeTarget, build.Binary),
+		Path:   filepath.Join("dist", runtimeTarget, build.Binary),
 		Ext:    "",
 	})
 	require.NoError(t, err)
@@ -619,7 +619,7 @@ func TestBuildWithDotGoDir(t *testing.T) {
 	require.NoError(t, Default.Build(ctx, build, api.Options{
 		Target: runtimeTarget,
 		Name:   build.Binary,
-		Path:   filepath.Join(folder, "dist", runtimeTarget, build.Binary),
+		Path:   filepath.Join("dist", runtimeTarget, build.Binary),
 		Ext:    "",
 	}))
 }
