@@ -328,7 +328,7 @@ func getChangeloger(ctx *context.Context) (changeloger, error) {
 }
 
 func newGithubChangeloger(ctx *context.Context) (changeloger, error) {
-	cli, err := client.NewGitHub(ctx, ctx.Token)
+	cli, err := client.NewGitHubReleaseNotesGenerator(ctx, ctx.Token)
 	if err != nil {
 		return nil, err
 	}
@@ -425,7 +425,7 @@ func (c *scmChangeloger) Log(ctx *context.Context) (string, error) {
 }
 
 type githubNativeChangeloger struct {
-	client client.GitHubClient
+	client client.ReleaseNotesGenerator
 	repo   client.Repo
 }
 
