@@ -4,6 +4,7 @@ import (
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/golden"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/require"
@@ -11,7 +12,7 @@ import (
 
 func TestDescribeBody(t *testing.T) {
 	changelog := "feature1: description\nfeature2: other description"
-	ctx := context.New(config.Project{})
+	ctx := testctx.New()
 	ctx.ReleaseNotes = changelog
 	out, err := describeBody(ctx)
 	require.NoError(t, err)
@@ -21,7 +22,7 @@ func TestDescribeBody(t *testing.T) {
 
 func TestDontEscapeHTML(t *testing.T) {
 	changelog := "<h1>test</h1>"
-	ctx := context.New(config.Project{})
+	ctx := testctx.New()
 	ctx.ReleaseNotes = changelog
 
 	out, err := describeBody(ctx)
@@ -31,14 +32,16 @@ func TestDontEscapeHTML(t *testing.T) {
 
 func TestDescribeBodyWithHeaderAndFooter(t *testing.T) {
 	changelog := "feature1: description\nfeature2: other description"
-	ctx := context.New(config.Project{
-		Release: config.Release{
-			Header: "## Yada yada yada\nsomething\n",
-			Footer: "\n---\n\nGet images at docker.io/foo/bar:{{.Tag}}\n\n---\n\nGet GoReleaser Pro at https://goreleaser.com/pro",
+	ctx := testctx.NewWithCfg(
+		config.Project{
+			Release: config.Release{
+				Header: "## Yada yada yada\nsomething\n",
+				Footer: "\n---\n\nGet images at docker.io/foo/bar:{{.Tag}}\n\n---\n\nGet GoReleaser Pro at https://goreleaser.com/pro",
+			},
 		},
-	})
-	ctx.ReleaseNotes = changelog
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0"}
+		testctx.WithCurrentTag("v1.0"),
+		func(ctx *context.Context) { ctx.ReleaseNotes = changelog },
+	)
 	out, err := describeBody(ctx)
 	require.NoError(t, err)
 
@@ -46,7 +49,7 @@ func TestDescribeBodyWithHeaderAndFooter(t *testing.T) {
 }
 
 func TestDescribeBodyWithInvalidHeaderTemplate(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Release: config.Release{
 			Header: "## {{ .Nop }\n",
 		},
@@ -56,7 +59,7 @@ func TestDescribeBodyWithInvalidHeaderTemplate(t *testing.T) {
 }
 
 func TestDescribeBodyWithInvalidFooterTemplate(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Release: config.Release{
 			Footer: "{{ .Nops }",
 		},
