@@ -9,6 +9,8 @@ import (
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/testctx"
+	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/stretchr/testify/assert"
@@ -143,11 +145,10 @@ func TestSBOMCatalogDefault(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(fmt.Sprintf("artifact=%q", test.configs[0].Artifacts), func(t *testing.T) {
-			ctx := &context.Context{
-				Config: config.Project{
-					SBOMs: test.configs,
-				},
-			}
+			testlib.CheckPath(t, "syft")
+			ctx := testctx.NewWithCfg(config.Project{
+				SBOMs: test.configs,
+			})
 			err := Pipe{}.Default(ctx)
 			if test.err {
 				require.Error(t, err)
@@ -164,37 +165,34 @@ func TestSBOMCatalogDefault(t *testing.T) {
 }
 
 func TestSBOMCatalogInvalidArtifacts(t *testing.T) {
-	ctx := context.New(config.Project{})
-	ctx.Config.SBOMs = []config.SBOM{
-		{Artifacts: "foo"},
-	}
+	ctx := testctx.NewWithCfg(config.Project{
+		SBOMs: []config.SBOM{{Artifacts: "foo"}},
+	})
 	err := Pipe{}.Run(ctx)
 	require.EqualError(t, err, "invalid list of artifacts to catalog: foo")
 }
 
 func TestSeveralSBOMsWithTheSameID(t *testing.T) {
-	ctx := &context.Context{
-		Config: config.Project{
-			SBOMs: []config.SBOM{
-				{
-					ID: "a",
-				},
-				{
-					ID: "a",
-				},
+	ctx := testctx.NewWithCfg(config.Project{
+		SBOMs: []config.SBOM{
+			{
+				ID: "a",
+			},
+			{
+				ID: "a",
 			},
 		},
-	}
+	})
 	require.EqualError(t, Pipe{}.Default(ctx), "found 2 sboms with the ID 'a', please fix your config")
 }
 
 func TestSkipCataloging(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("skip SBOM cataloging", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			SBOMs: []config.SBOM{
 				{
 					Artifacts: "all",
@@ -206,7 +204,7 @@ func TestSkipCataloging(t *testing.T) {
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			SBOMs: []config.SBOM{
 				{
 					Artifacts: "all",
@@ -228,81 +226,69 @@ func TestSBOMCatalogArtifacts(t *testing.T) {
 		{
 			desc:           "catalog errors",
 			expectedErrMsg: "cataloging artifacts: exit failed",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{
-							Artifacts: "binary",
-							Cmd:       "exit",
-							Args:      []string{"1"},
-						},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{
+						Artifacts: "binary",
+						Cmd:       "exit",
+						Args:      []string{"1"},
 					},
 				},
-			),
+			}),
 		},
 		{
 			desc:           "invalid args template",
 			expectedErrMsg: `cataloging artifacts failed: arg "${FOO}-{{ .foo }{{}}{": invalid template: template: tmpl:1: unexpected "}" in operand`,
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{
-							Artifacts: "binary",
-							Cmd:       "exit",
-							Args:      []string{"${FOO}-{{ .foo }{{}}{"},
-						},
-					},
-					Env: []string{
-						"FOO=BAR",
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{
+						Artifacts: "binary",
+						Cmd:       "exit",
+						Args:      []string{"${FOO}-{{ .foo }{{}}{"},
 					},
 				},
-			),
+				Env: []string{
+					"FOO=BAR",
+				},
+			}),
 		},
 		{
 			desc: "catalog source archives",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{Artifacts: "source"},
-					},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{Artifacts: "source"},
 				},
-			),
+			}),
 			sbomPaths: []string{"artifact5.tar.gz.sbom"},
 			sbomNames: []string{"artifact5.tar.gz.sbom"},
 		},
 		{
 			desc: "catalog archives",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{Artifacts: "archive"},
-					},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{Artifacts: "archive"},
 				},
-			),
+			}),
 			sbomPaths: []string{"artifact1.sbom", "artifact2.sbom"},
 			sbomNames: []string{"artifact1.sbom", "artifact2.sbom"},
 		},
 		{
 			desc: "catalog linux packages",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{Artifacts: "package"},
-					},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{Artifacts: "package"},
 				},
-			),
+			}),
 			sbomPaths: []string{"package1.deb.sbom"},
 			sbomNames: []string{"package1.deb.sbom"},
 		},
 		{
 			desc: "catalog binaries",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{Artifacts: "binary"},
-					},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{Artifacts: "binary"},
 				},
-			),
+			}),
 			sbomPaths: []string{
 				"artifact3-name_1.2.2_linux_amd64.sbom",
 				"artifact4-name_1.2.2_linux_amd64.sbom",
@@ -314,48 +300,44 @@ func TestSBOMCatalogArtifacts(t *testing.T) {
 		},
 		{
 			desc: "manual cataloging",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{
-							Artifacts: "any",
-							Args: []string{
-								"--file",
-								"$document0",
-								"--output",
-								"spdx-json",
-								"artifact5.tar.gz",
-							},
-							Documents: []string{
-								"final.sbom",
-							},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{
+						Artifacts: "any",
+						Args: []string{
+							"--file",
+							"$document0",
+							"--output",
+							"spdx-json",
+							"artifact5.tar.gz",
+						},
+						Documents: []string{
+							"final.sbom",
 						},
 					},
 				},
-			),
+			}),
 			sbomPaths: []string{"final.sbom"},
 			sbomNames: []string{"final.sbom"},
 		},
 		{
 			desc: "multiple SBOM configs",
-			ctx: context.New(
-				config.Project{
-					Env: []string{
-						"SBOM_SUFFIX=s2-ish",
+			ctx: testctx.NewWithCfg(config.Project{
+				Env: []string{
+					"SBOM_SUFFIX=s2-ish",
+				},
+				SBOMs: []config.SBOM{
+					{
+						ID:        "s1",
+						Artifacts: "binary",
 					},
-					SBOMs: []config.SBOM{
-						{
-							ID:        "s1",
-							Artifacts: "binary",
-						},
-						{
-							ID:        "s2",
-							Artifacts: "archive",
-							Documents: []string{"{{ .ArtifactName }}.{{ .Env.SBOM_SUFFIX }}.sbom"},
-						},
+					{
+						ID:        "s2",
+						Artifacts: "archive",
+						Documents: []string{"{{ .ArtifactName }}.{{ .Env.SBOM_SUFFIX }}.sbom"},
 					},
 				},
-			),
+			}),
 			sbomPaths: []string{
 				"artifact1.s2-ish.sbom",
 				"artifact2.s2-ish.sbom",
@@ -371,16 +353,14 @@ func TestSBOMCatalogArtifacts(t *testing.T) {
 		},
 		{
 			desc: "catalog artifacts with filtered by ID",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{
-							Artifacts: "binary",
-							IDs:       []string{"foo"},
-						},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{
+						Artifacts: "binary",
+						IDs:       []string{"foo"},
 					},
 				},
-			),
+			}),
 			sbomPaths: []string{
 				"artifact3-name_1.2.2_linux_amd64.sbom",
 			},
@@ -390,28 +370,26 @@ func TestSBOMCatalogArtifacts(t *testing.T) {
 		},
 		{
 			desc: "catalog binary artifacts with env in arguments",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{
-							Artifacts: "binary",
-							Args: []string{
-								"--file",
-								"$document",
-								"--output",
-								"spdx-json",
-								"$artifact",
-							},
-							Documents: []string{
-								"{{ .ArtifactName }}.{{ .Env.TEST_USER }}.sbom",
-							},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{
+						Artifacts: "binary",
+						Args: []string{
+							"--file",
+							"$document",
+							"--output",
+							"spdx-json",
+							"$artifact",
+						},
+						Documents: []string{
+							"{{ .ArtifactName }}.{{ .Env.TEST_USER }}.sbom",
 						},
 					},
-					Env: []string{
-						"TEST_USER=test-user-name",
-					},
 				},
-			),
+				Env: []string{
+					"TEST_USER=test-user-name",
+				},
+			}),
 			sbomPaths: []string{
 				"artifact3-name.test-user-name.sbom",
 				"artifact4.test-user-name.sbom",
@@ -423,16 +401,14 @@ func TestSBOMCatalogArtifacts(t *testing.T) {
 		},
 		{
 			desc: "cataloging 'any' artifacts fails",
-			ctx: context.New(
-				config.Project{
-					SBOMs: []config.SBOM{
-						{
-							Artifacts: "any",
-							Cmd:       "false",
-						},
+			ctx: testctx.NewWithCfg(config.Project{
+				SBOMs: []config.SBOM{
+					{
+						Artifacts: "any",
+						Cmd:       "false",
 					},
 				},
-			),
+			}),
 			expectedErrMsg: "cataloging artifacts: false failed: exit status 1: ",
 		},
 	}
@@ -446,6 +422,7 @@ func TestSBOMCatalogArtifacts(t *testing.T) {
 
 func testSBOMCataloging(tb testing.TB, ctx *context.Context, sbomPaths, sbomNames []string, expectedErrMsg string) {
 	tb.Helper()
+	testlib.CheckPath(tb, "syft")
 	tmpdir := tb.TempDir()
 
 	ctx.Config.Dist = tmpdir
@@ -738,10 +715,9 @@ func Test_templateNames(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Dist: tt.dist,
-			})
-			ctx.Version = tt.version
+			}, testctx.WithVersion(tt.version))
 
 			cfg := tt.cfg
 			require.NoError(t, setConfigDefaults(&cfg))
@@ -774,3 +750,13 @@ func Test_templateNames(t *testing.T) {
 		})
 	}
 }
+
+func TestDependencies(t *testing.T) {
+	ctx := testctx.NewWithCfg(config.Project{
+		SBOMs: []config.SBOM{
+			{Cmd: "syft"},
+			{Cmd: "foobar"},
+		},
+	})
+	require.Equal(t, []string{"syft", "foobar"}, Pipe{}.Dependencies(ctx))
+}
