@@ -3,43 +3,48 @@ package main
 import (
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/golden"
 	"github.com/stretchr/testify/require"
 )
 
 func TestVersion(t *testing.T) {
+	const goVersion = "go1.20.3"
+	const compiler = "gc"
+	const platform = "linux/amd64"
+
 	for name, tt := range map[string]struct {
 		version, commit, date, builtBy string
-		out                            string
 	}{
-		"all empty": {
-			out: website,
-		},
+		"all empty": {},
 		"complete": {
 			version: "1.2.3",
 			date:    "12/12/12",
 			commit:  "aaaa",
 			builtBy: "me",
-			out:     "1.2.3\ncommit: aaaa\nbuilt at: 12/12/12\nbuilt by: me" + website,
 		},
 		"only version": {
 			version: "1.2.3",
-			out:     "1.2.3" + website,
 		},
 		"version and date": {
 			version: "1.2.3",
 			date:    "12/12/12",
-			out:     "1.2.3\nbuilt at: 12/12/12" + website,
 		},
 		"version, date, built by": {
 			version: "1.2.3",
 			date:    "12/12/12",
 			builtBy: "me",
-			out:     "1.2.3\nbuilt at: 12/12/12\nbuilt by: me" + website,
 		},
 	} {
 		tt := tt
 		t.Run(name, func(t *testing.T) {
-			require.Equal(t, tt.out, buildVersion(tt.version, tt.commit, tt.date, tt.builtBy))
+			v := buildVersion(tt.version, tt.commit, tt.date, tt.builtBy)
+			v.GoVersion = goVersion
+			v.Compiler = compiler
+			v.Platform = platform
+			out, err := v.JSONString()
+			require.NoError(t, err)
+
+			golden.RequireEqualJSON(t, []byte(out))
 		})
 	}
 }
